Index: chrome/browser/cocoa/extension_installed_bubble_controller.h |
diff --git a/chrome/browser/cocoa/extension_installed_bubble_controller.h b/chrome/browser/cocoa/extension_installed_bubble_controller.h |
index e5f50a3d9a1d9cad667e8958beee697e0f8f8af8..7d0417f10c736776de07115faaaf8895210a992c 100644 |
--- a/chrome/browser/cocoa/extension_installed_bubble_controller.h |
+++ b/chrome/browser/cocoa/extension_installed_bubble_controller.h |
@@ -33,8 +33,9 @@ const int kInnerVerticalMargin = 10; |
// We use a different kind of notification for each of these extension types. |
typedef enum { |
kBrowserAction, |
- kPageAction, |
- kGeneric |
+ kGeneric, |
+ kOmniboxKeyword, |
+ kPageAction |
} ExtensionType; |
} |
@@ -68,7 +69,8 @@ typedef enum { |
IBOutlet HoverCloseButton* closeButton_; |
IBOutlet NSImageView* iconImage_; |
IBOutlet NSTextField* extensionInstalledMsg_; |
- IBOutlet NSTextField* pageActionInfoMsg_; // Only shown for page actions. |
+ // Only shown for page actions and omnibox keywords. |
+ IBOutlet NSTextField* extraInfoMsg_; |
IBOutlet NSTextField* extensionInstalledInfoMsg_; |
} |
@@ -102,7 +104,7 @@ typedef enum { |
- (int)calculateWindowHeight; |
- (void)setMessageFrames:(int)newWindowHeight; |
- (NSRect)getExtensionInstalledMsgFrame; |
-- (NSRect)getPageActionInfoMsgFrame; |
+- (NSRect)getExtraInfoMsgFrame; |
- (NSRect)getExtensionInstalledInfoMsgFrame; |
@end // ExtensionInstalledBubbleController(ExposedForTesting) |